﻿using System.Collections.ObjectModel;
using System.Diagnostics;
using System.Linq;
using System.Threading.Tasks;
using System.Windows;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.GridView;

namespace IteratingOverRowsDemo
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
            Loaded += MainWindow_Loaded;
        }

        private async void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            myGridView.ItemsSource = await GetBooksAsync();
        }

        private void ButtonBase_OnClick(object sender, RoutedEventArgs e)
        {
            // this is to get the currently rendered rows
            var rows = this.myGridView.ChildrenOfType<GridViewRow>();

            // myGridView.Items will get you all the row items, which you can iterate over
            foreach (var item in myGridView.Items)
            {
                var book = item as Book;

                // now you can check the DataItem for a particular value
                if (book?.Price < 10)
                {
                    Debug.WriteLine($"{book.Title} is less than 10 dollars");
                }
            }

            // To confirm the counts
            OutputTextBlock.Text = $"RadGridView has rendered {rows.Count()} items out of {myGridView.Items.ItemCount}";
        }

        private async Task<ObservableCollection<Book>> GetBooksAsync()
        {
            return await Task.Run(() =>
            {
                var books = new ObservableCollection<Book>();

                for (int i = 0; i < 1000; i++)
                {
                    books.Add(new Book
                    {
                        Title = $"Book {i}",
                        Price = i
                    });
                }

                return books;
            });
        }
    }

    public class Book
    {
        public string Title { get; set; }
        public double Price { get; set; }
    }
}
